summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/skills2.cc
diff options
context:
space:
mode:
authordolorous <dolorous@c06c8d41-db1a-0410-9941-cceddc491573>2008-11-02 05:46:09 +0000
committerdolorous <dolorous@c06c8d41-db1a-0410-9941-cceddc491573>2008-11-02 05:46:09 +0000
commit8eecdc8f479ffc662ba86387448953bf11b95e5c (patch)
tree51edaffd4ca52cdd7fef8e37dbf06dcaa8cd5d2d /crawl-ref/source/skills2.cc
parent74269d47bbf31b70af8bcc7f15161ec8ee0a061b (diff)
downloadcrawl-ref-8eecdc8f479ffc662ba86387448953bf11b95e5c.tar.gz
crawl-ref-8eecdc8f479ffc662ba86387448953bf11b95e5c.zip
Implement [2169326]: Put back some adjective skill titles.
git-svn-id: https://crawl-ref.svn.sourceforge.net/svnroot/crawl-ref/trunk@7339 c06c8d41-db1a-0410-9941-cceddc491573
Diffstat (limited to 'crawl-ref/source/skills2.cc')
-rw-r--r--crawl-ref/source/skills2.cc25
1 files changed, 16 insertions, 9 deletions
diff --git a/crawl-ref/source/skills2.cc b/crawl-ref/source/skills2.cc
index c59f9a86e9..d716a2ca8e 100644
--- a/crawl-ref/source/skills2.cc
+++ b/crawl-ref/source/skills2.cc
@@ -64,8 +64,9 @@ typedef skill_title_key_t stk;
// Referring to the skill itself is fine ("Transmuter") but not impressive.
// No overlaps, high diversity.
// Replace @genus@ with lowercase genus, @Genus@ with uppercase, and %s
// with special cases defined below, including but not limited to species.
// NOTE: Even though %s could be used with most of these, remember that
// the character's race will be listed on the next line. It's only really
@@ -77,22 +78,22 @@ const char *skills[50][6] =
// Skill name levels 1-7 levels 8-14 levels 15-20 levels 21-26 level 27
{"Fighting", "Skirmisher", "Fighter", "Warrior", "Slayer", "Conqueror"}, // 0
{"Short Blades", "Cutter", "Slicer", "Swashbuckler", "Blademaster", "Eviscerator"},
- {"Long Blades", "Slasher", "Carver", "Fencer", "@Genus@ Blade", "Swordmaster"},
+ {"Long Blades", "Slasher", "Carver", "Fencer", "@Adj@ Blade", "Swordmaster"},
{NULL}, // 3- was: great swords {dlb}
{"Axes", "Chopper", "Cleaver", "Hacker", "Severer", "Executioner"},
{"Maces & Flails", "Cudgeler", "Basher", "Bludgeoner", "Shatterer", "Skullcrusher"}, // 5
- {"Polearms", "Poker", "Spear-Bearer", "Impaler", "Phalangite", "@Genus@ Porcupine"},
+ {"Polearms", "Poker", "Spear-Bearer", "Impaler", "Phalangite", "@Adj@ Porcupine"},
{"Staves", "Twirler", "Cruncher", "Stickfighter", "Pulveriser", "Chief of Staff"},
- {"Slings", "Vandal", "Slinger", "Whirler", "Slingshot", "@Genus@ Catapult"},
+ {"Slings", "Vandal", "Slinger", "Whirler", "Slingshot", "@Adj@ Catapult"},
{"Bows", "Shooter", "Archer", "Marks@genus@", "Crack Shot", "Merry @Genus@"},
- {"Crossbows", "Bolt Thrower", "Quickloader", "Sharpshooter", "Sniper", "@Genus@ Arbalest"}, // 10
+ {"Crossbows", "Bolt Thrower", "Quickloader", "Sharpshooter", "Sniper", "@Adj@ Arbalest"}, // 10
{"Darts", "Dart Thrower", "Hurler", "Hedgehog", "Darts Champion", "Perforator"},
- {"Throwing", "Chucker", "Thrower", "Deadly Accurate", "Hawkeye", "@Genus@ Ballista"},
+ {"Throwing", "Chucker", "Thrower", "Deadly Accurate", "Hawkeye", "@Adj@ Ballista"},
{"Armour", "Covered", "Protected", "Tortoise", "Impregnable", "Invulnerable"},
{"Dodging", "Ducker", "Nimble", "Spry", "Acrobat", "Intangible"},
{"Stealth", "Sneak", "Covert", "Unseen", "Imperceptible", "Ninja"}, // 15
{"Stabbing", "Miscreant", "Blackguard", "Backstabber", "Cutthroat", "Politician"},
- {"Shields", "Shield-Bearer", "Hoplite", "Blocker", "Peltast", "@Genus@ Barricade"},
+ {"Shields", "Shield-Bearer", "Hoplite", "Blocker", "Peltast", "@Adj@ Barricade"},
{"Traps & Doors", "Scout", "Disarmer", "Vigilant", "Perceptive", "Dungeon Master"},
// STR based fighters, for DEX/martial arts titles see below
{"Unarmed Combat", "Ruffian", "Grappler", "Brawler", "Wrestler", "@Weight@weight Champion"},
@@ -108,7 +109,7 @@ const char *skills[50][6] =
{"Enchantments", "Charm-Maker", "Infuser", "Bewitcher", "Enchanter", "Spellbinder"},
{"Summonings", "Caller", "Summoner", "Convoker", "Demonologist", "Hellbinder"},
{"Necromancy", "Grave Robber", "Reanimator", "Necromancer", "Thanatomancer", "@Genus_Short@ of Death"},
- {"Translocations", "Grasshopper", "Placeless @Genus@", "Blinker", "Portalist", "Plane @Walker@"}, // 30
+ {"Translocations", "Grasshopper", "Placeless @Genus@", "Blinker", "Portalist", "Plane @Walker@"}, // 30
{"Transmigration", "Changer", "Transmogrifier", "Alchemist", "Malleable", "Shapeless @Genus@"},
{"Divinations", "Seer", "Soothsayer", "Diviner", "Augur", "Oracle"},
@@ -1923,6 +1924,11 @@ int str_to_skill(const std::string &skill)
return (SK_FIGHTING);
}
+static std::string _stk_adj_cap()
+{
+ return species_name(Skill_Species, 1, false, true);
+}
+
static std::string _stk_genus_cap()
{
return species_name(Skill_Species, 1, true, false);
@@ -1979,6 +1985,7 @@ static std::string _stk_weight()
}
static skill_title_key_t _skill_title_keys[] = {
+ stk("Adj", _stk_adj_cap),
stk("Genus", _stk_genus_cap),
stk("genus", _stk_genus_nocap),
stk("Genus_Short", _stk_genus_short_cap),
@@ -64,8 +64,9 @@ typedef skill_title_key_t stk;
// Referring to the skill itself is fine ("Transmuter") but not impressive.
// No overlaps, high diversity.
-// Replace @genus@ with lowercase genus, @Genus@ with uppercase, and %s
-// with special cases defined below, including but not limited to species.
+// Replace @Adj@ with uppercase adjective form, @genus@ with lowercase genus,
+// @Genus@ with uppercase genus, and %s with special cases defined below,
+// including but not limited to species.
// NOTE: Even though %s could be used with most of these, remember that
// the character's race will be listed on the next line. It's only really